[gtk+/rendering-cleanup: 131/141] quartz: Compare visuals for RGBA, not colormaps
- From: Benjamin Otte <otte src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gtk+/rendering-cleanup: 131/141] quartz: Compare visuals for RGBA, not colormaps
- Date: Sat, 11 Sep 2010 03:11:38 +0000 (UTC)
commit bb68c93c4424f88f1b85fb6b7f7c817bbcfed71c
Author: Benjamin Otte <otte redhat com>
Date: Sun Aug 29 02:16:27 2010 +0200
quartz: Compare visuals for RGBA, not colormaps
gdk/quartz/GdkQuartzView.c | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/gdk/quartz/GdkQuartzView.c b/gdk/quartz/GdkQuartzView.c
index 656f8e2..8c6132b 100644
--- a/gdk/quartz/GdkQuartzView.c
+++ b/gdk/quartz/GdkQuartzView.c
@@ -61,8 +61,8 @@
if (GDK_WINDOW_DESTROYED (gdk_window))
return YES;
- /* A view is opaque if its GdkWindow doesn't have the RGBA colormap */
- return gdk_drawable_get_colormap (gdk_window) != gdk_screen_get_rgba_colormap (_gdk_screen);
+ /* A view is opaque if its GdkWindow doesn't have the RGBA visual */
+ return gdk_window_get_visual (gdk_window) != gdk_screen_get_rgba_visual (_gdk_screen);
}
-(void)drawRect:(NSRect)rect
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]